pub enum Mode {
Teleop,
Auto,
Test,
}Expand description
The commanded mode of the robot.
Variants
Teleop
The is being controlled by a user directly.
Auto
The robot is being controlled by a user code autonomously.
Test
The robot is being controlled by a user directly for testing purposes.