pub struct JoystickData {
pub plugged_in: bool,
pub axies: [f32; 8],
pub buttons: [u8; 6],
pub povs: [i16; 3],
}Expand description
The data for a single joystick.
Fields
plugged_in: boolIf the joystick is plugged in.
axies: [f32; 8]An array of the joystick axies, this can be lossy if the joystick has more than 8 axies.
An array of the joystick buttons, this can be lossy if the joystick has more than 48 buttons. This array sub should treated as 8*6 bits where each bit is a button.
povs: [i16; 3]An array of the joystick povs, this can be lossy if the joystick has more than 3 povs.