HAL

Struct HAL 

pub struct HAL { /* private fields */ }
A struct that defines a platform specific HAL(Hardware Abstraction Layer) using a Driver.

Using a HAL allows for significant platform changes without having to rewrite much code. HALs are also useful for testing/sim as they can be mocked.

HALs also allow for easier community support for exotic platforms.

Implementations

Source

impl HAL

pub fn init<Driver: HALDriver>()

Initializes the HAL, can only be called once across every HAL.

Panics

If HAL has already been initialized this will panic If the used driver is not zero sized this will panic

pub fn init_sim<Driver: SimHALDriver>()

Initializes the HAL with support for sim, can only be called once across every HAL.

Panics

If HAL has already been initialized this will panic. If the used driver is not zero sized this will panic.

pub fn cleanup(&self)

Cleans up the HAL

pub const fn driver_name(&self) -> &'static str

Returns the name of the current HALDriver.

pub const fn notifier_api(&self) -> NotifierVTable

Returns the NotifierVTable for the current HALDriver.

pub const fn watchdog_api(&self) -> WatchdogVTable

Returns the WatchdogVTable for the current HALDriver.

pub const fn gpio_api(&self) -> GPIOVTable

Returns the GPIOVTable for the current HALDriver.

pub const fn station_interface_api(&self) -> StationInterfaceVTable

Returns the StationInterfaceVTable for the current HALDriver.