NotSimError

Struct NotSimError 

pub struct NotSimError;
An error that occurs when a function is called that is only available when the HAL is initialized with sim support but the HAL is not initialized with sim support.