SimHALDriver

Trait SimHALDriver 

pub trait SimHALDriver:
    HALDriver
    + SimGPIODriver
    + SimWatchdogDriver { }
A trait that defines a HAL(Hardware Abstraction Layer) Driver with sim support. Should be implemented by a platform specific HAL Driver Zero Sized Type.

A HAL with sim support should implement this trait instead of HALDriver, because of this a HAL with sim support can be used in as a HALDriver too.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors