pub struct FrcStructDesc {
pub schema_supplier: fn() -> String,
pub type_str: &'static str,
pub size: usize,
}Expand description
A description of a structure, used for serialization and deserialization
Fields
schema_supplier: fn() -> StringA function that returns the schema of the structure, this is needed because the schema cannot be made in a const context
type_str: &'static strThe type of the structure, typically the name of the rust type
size: usizeThe size of the structure in bytes