pub struct FrcStructDescDB;Expand description
A global database of structure descriptions
Implementations
Sourceimpl FrcStructDescDB
impl FrcStructDescDB
Sourcepub fn add(desc: FrcStructDesc)
pub fn add(desc: FrcStructDesc)
Adds a structure description to the global database,
this is a runtime equivalent of the inventory::submit! macro.
Sourcepub fn add_ref(desc: &'static FrcStructDesc)
pub fn add_ref(desc: &'static FrcStructDesc)
Adds a structure description to the global database,
this is a runtime equivalent of the inventory::submit! macro.
Sourcepub fn contains_type(type_str: &str) -> bool
pub fn contains_type(type_str: &str) -> bool
Checks if the global database contains a structure description for a given type
Sourcepub fn get(type_str: &str) -> Option<&'static FrcStructDesc>
pub fn get(type_str: &str) -> Option<&'static FrcStructDesc>
Gets a structure description from the global database for a given type, returns None if the type is not found