pub struct FrcStructureBytes {
pub desc: &'static FrcStructDesc,
pub count: usize,
pub data: Box<[u8]>,
}Expand description
A way of defining any number of same typed FrcStructures
in a single binary heap.
The type information and struct count is also coupled with the binary data
Fields
desc: &'static FrcStructDescThe description of the structure types and layout
count: usizeThe number of structs packed into data
data: Box<[u8]>The binary data of the structs
Implementations
Sourceimpl FrcStructureBytes
impl FrcStructureBytes
Sourcepub fn from_parts(
desc: &'static FrcStructDesc,
count: usize,
data: Box<[u8]>,
) -> Self
pub fn from_parts( desc: &'static FrcStructDesc, count: usize, data: Box<[u8]>, ) -> Self
Creates a new FrcStructureBytes from a description, count, and data