pub struct FrcEntry {
pub timestamp: FrcTimestamp,
pub value: FrcValue,
pub key: &'static str,
}Expand description
A timestamped value with a key attached, important for passing to pub/sub logging systems
Fields
timestamp: FrcTimestampThe timestamp of the value, typically the uptime of the robot if running on the robot and the unix epoch if running on desktop
value: FrcValueThe value
key: &'static strThe key