pub struct FrcTimestampedValue {
pub timestamp: FrcTimestamp,
pub value: FrcValue,
}Expand description
An FrcValue with a FrcTimestamp attached,
important for passing to logging systems
Fields
timestamp: FrcTimestampThe timestamp of the value, typically the uptime of the robot if running on the robot and the unix epoch if running on desktop (non sim)
value: FrcValueThe value
Implementations
Sourceimpl FrcTimestampedValue
impl FrcTimestampedValue
Sourcepub const fn new(timestamp: FrcTimestamp, value: FrcValue) -> Self
pub const fn new(timestamp: FrcTimestamp, value: FrcValue) -> Self
Creates a new timestamped value
Sourcepub const fn is_after_timestamp(&self, timestamp: FrcTimestamp) -> bool
pub const fn is_after_timestamp(&self, timestamp: FrcTimestamp) -> bool
Checks if the timestamp is after the given timestamp
Sourcepub const fn is_after_other(&self, other: &Self) -> bool
pub const fn is_after_other(&self, other: &Self) -> bool
Checks if the timestamp is after the given timestamped value
Sourcepub const fn is_before_timestamp(&self, timestamp: FrcTimestamp) -> bool
pub const fn is_before_timestamp(&self, timestamp: FrcTimestamp) -> bool
Checks if the timestamp is before the given timestamp
Sourcepub const fn is_before_other(&self, other: &Self) -> bool
pub const fn is_before_other(&self, other: &Self) -> bool
Checks if the timestamp is before the given timestamped value