StationInterfaceVTable

Struct StationInterfaceVTable 

pub struct StationInterfaceVTable { /* private fields */ }
A struct that defines a platform specific user control station interface for user code.

Implementations

Source

impl StationInterfaceVTable

pub fn send_console_line_error( &self, line: &str, location: &str, callstack: &str, )

Will send an error message to the driver station console, driver station has to support error messages.

pub fn send_console_line_warn(&self, line: &str, location: &str)

Will send a warning message to the driver station console, if the driver station does not support warnings it will be sent as an error.

pub fn send_console_line_info(&self, line: &str, location: &str)

Will send an info message to the driver station console, driver station has to support info messages.

pub fn send_console_line_debug(&self, line: &str, location: &str)

Will send a debug message to the driver station console, if the driver station does not support debug messages it will be ignored.

pub fn refresh(&self)

Should update all process local station data from the driver station latest values.

pub fn get_station_data(&self) -> StationData

Should return the latest station data.

pub fn is_enabled(&self) -> bool

Returns if the latest station data declares the robot enabled.

pub fn is_disabled(&self) -> bool

Returns if the latest station data declares the robot disabled.

pub fn is_estopped(&self) -> bool

Returns if the latest station data declares the robot estopped.

pub fn is_teleop(&self) -> bool

Returns if the latest station data declares the robot in teleop mode.

pub fn is_auto(&self) -> bool

Returns if the latest station data declares the robot in auto mode.

pub fn is_test(&self) -> bool

Returns if the latest station data declares the robot in test mode.

pub fn is_fms_attached(&self) -> bool

Returns if the latest station data declares the robot is attached to the FMS.

pub fn is_station_attached(&self) -> bool

Returns if the latest station data declares the robot is attached to a station.

pub fn get_station_team_number(&self) -> u16

Returns the team number of the latest station data.